==> haskell-ghc-typelits-extra-0.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-7PQmaauSTodFTzWoCDSnja
key: ghc-typelits-extra-0.3-7PQmaauSTodFTzWoCDSnja
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: dd0bd5023392b120369860ac62e20a26
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-7PQmaauSTodFTzWoCDSnja
depends:
    base-4.12.0.0 ghc-8.6.5 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
    ghc-typelits-knownnat-0.6-CMXB9LTei6QDzcnFZH9FZz
    ghc-typelits-natnormalise-0.6.2-6S9zjZfnE9d8DosnLn44Ra
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-extra-0.3-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-4oYetGa8sqb8wgInPY17Kb
key: ghc-typelits-extra-0.3-4oYetGa8sqb8wgInPY17Kb
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: da2ff14997737da39d892472569eec34
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-4oYetGa8sqb8wgInPY17Kb
depends:
    base-4.12.0.0 ghc-8.6.5 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
    ghc-typelits-knownnat-0.6-5w5Pxt2JwCh3hs27Rp6uCB
    ghc-typelits-natnormalise-0.6.2-6S9zjZfnE9d8DosnLn44Ra
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
